@@ -37,6 +37,17 @@ class ParserTest extends TestCase
         $parser->parse($lexer->tokenize('foo'), [0]);
     }
 
+    public function testParsePrimaryExpressionWithUnknownFunctionThrows()
+    {
+        $parser = new Parser([]);
+        $stream = (new Lexer())->tokenize('foo()');
+
+        $this->expectException(SyntaxError::class);
+        $this->expectExceptionMessage('The function "foo" does not exist around position 1 for expression `foo()`.');
+
+        $parser->parse($stream);
+    }
+
     /**
      * @dataProvider getParseData
      */
@@ -136,6 +147,43 @@ class ParserTest extends TestCase
                 new Node\BinaryNode('matches', new Node\ConstantNode('foo'), new Node\ConstantNode('/foo/')),
                 '"foo" matches "/foo/"',
             ],
+            [
+                new Node\BinaryNode('starts with', new Node\ConstantNode('foo'), new Node\ConstantNode('f')),
+                '"foo" starts with "f"',
+            ],
+            [
+                new Node\BinaryNode('ends with', new Node\ConstantNode('foo'), new Node\ConstantNode('f')),
+                '"foo" ends with "f"',
+            ],
+            [
+                new Node\BinaryNode('contains', new Node\ConstantNode('foo'), new Node\ConstantNode('f')),
+                '"foo" contains "f"',
+            ],
+            [
+                new Node\GetAttrNode(new Node\NameNode('foo'), new Node\ConstantNode('bar', true, true), new Node\ArgumentsNode(), Node\GetAttrNode::PROPERTY_CALL),
+                'foo?.bar',
+                ['foo'],
+            ],
+            [
+                new Node\GetAttrNode(new Node\NameNode('foo'), new Node\ConstantNode('bar', true, true), new Node\ArgumentsNode(), Node\GetAttrNode::METHOD_CALL),
+                'foo?.bar()',
+                ['foo'],
+            ],
+            [
+                new Node\GetAttrNode(new Node\NameNode('foo'), new Node\ConstantNode('not', true, true), new Node\ArgumentsNode(), Node\GetAttrNode::METHOD_CALL),
+                'foo?.not()',
+                ['foo'],
+            ],
+            [
+                new Node\NullCoalesceNode(new Node\GetAttrNode(new Node\NameNode('foo'), new Node\ConstantNode('bar', true), new Node\ArgumentsNode(), Node\GetAttrNode::PROPERTY_CALL), new Node\ConstantNode('default')),
+                'foo.bar ?? "default"',
+                ['foo'],
+            ],
+            [
+                new Node\NullCoalesceNode(new Node\GetAttrNode(new Node\NameNode('foo'), new Node\ConstantNode('bar'), new Node\ArgumentsNode(), Node\GetAttrNode::ARRAY_CALL), new Node\ConstantNode('default')),
+                'foo["bar"] ?? "default"',
+                ['foo'],
+            ],
 
             // chained calls
             [
@@ -189,6 +237,10 @@ class ParserTest extends TestCase
                 new Node\BinaryNode('..', new Node\ConstantNode(0), new Node\ConstantNode(3)),
                 '0..3',
             ],
+            [
+                new Node\BinaryNode('+', new Node\ConstantNode(0), new Node\ConstantNode(0.1)),
+                '0+.1',
+            ],
         ];
     }
 
@@ -243,7 +295,7 @@ class ParserTest extends TestCase
     /**
      * @dataProvider getLintData
      */
-    public function testLint($expression, $names, string $exception = null)
+    public function testLint($expression, $names, ?string $exception = null)
     {
         if ($exception) {
             $this->expectException(SyntaxError::class);
@@ -265,6 +317,10 @@ class ParserTest extends TestCase
                 'expression' => 'foo["some_key"].callFunction(a ? b)',
                 'names' => ['foo', 'a', 'b'],
             ],
+            'valid expression with null safety' => [
+                'expression' => 'foo["some_key"]?.callFunction(a ? b)',
+                'names' => ['foo', 'a', 'b'],
+            ],
             'allow expression without names' => [
                 'expression' => 'foo.bar',
                 'names' => null,
