@@ -28,35 +28,12 @@ use Symfony\Component\Form\ResolvedFormTypeFactory;
 
 class FormDataCollectorTest extends TestCase
 {
-    /**
-     * @var FormDataCollector
-     */
-    private $dataCollector;
-
-    /**
-     * @var FormFactory
-     */
-    private $factory;
-
-    /**
-     * @var Form
-     */
-    private $form;
-
-    /**
-     * @var Form
-     */
-    private $childForm;
-
-    /**
-     * @var FormView
-     */
-    private $view;
-
-    /**
-     * @var FormView
-     */
-    private $childView;
+    private FormDataCollector $dataCollector;
+    private FormFactory $factory;
+    private FormInterface $form;
+    private FormInterface $childForm;
+    private FormView $view;
+    private FormView $childView;
 
     protected function setUp(): void
     {
@@ -335,9 +312,7 @@ class FormDataCollectorTest extends TestCase
         $form1View = new FormView();
         $form2View = new FormView();
         $child1View = new FormView();
-        $child1View->vars['is_selected'] = function ($choice, array $values) {
-            return \in_array($choice, $values, true);
-        };
+        $child1View->vars['is_selected'] = fn ($choice, array $values) => \in_array($choice, $values, true);
 
         $form1->add($child1);
         $form2->add($child1);
