@@ -12,12 +12,13 @@ return [
         'bo_IN' => 'تبيتائي (भारत)',
         'br_FR' => 'بريٽن (फ़्रांस)',
         'bs_Cyrl' => 'بوسنيائي (सिरिलिक)',
-        'bs_Cyrl_BA' => 'بوسنيائي (सिरिलिक, بوسنيا ۽ ھرزيگوينا)',
+        'bs_Cyrl_BA' => 'بوسنيائي (सिरिलिक, بوسنيا ۽ هرزوگووينا)',
         'bs_Latn' => 'بوسنيائي (लैटिन)',
-        'bs_Latn_BA' => 'بوسنيائي (लैटिन, بوسنيا ۽ ھرزيگوينا)',
+        'bs_Latn_BA' => 'بوسنيائي (लैटिन, بوسنيا ۽ هرزوگووينا)',
         'ca_FR' => 'ڪيٽالان (फ़्रांस)',
         'ca_IT' => 'ڪيٽالان (इटली)',
         'ce_RU' => 'چیچن (रशिया)',
+        'cv_RU' => 'چو واش (रशिया)',
         'cy_GB' => 'ويلش (बरतानी)',
         'de' => 'जर्मन',
         'de_AT' => 'जर्मन (آسٽريا)',
@@ -31,7 +32,7 @@ return [
         'en_001' => 'अंगरेज़ी (دنيا)',
         'en_150' => 'अंगरेज़ी (يورپ)',
         'en_AE' => 'अंगरेज़ी (متحده عرب امارات)',
-        'en_AG' => 'अंगरेज़ी (انٽيگا ۽ باربوڊا)',
+        'en_AG' => 'अंगरेज़ी (انٽيگا ۽ باربد)',
         'en_AI' => 'अंगरेज़ी (انگويلا)',
         'en_AS' => 'अंगरेज़ी (آمريڪي ساموا)',
         'en_AT' => 'अंगरेज़ी (آسٽريا)',
@@ -59,7 +60,7 @@ return [
         'en_FK' => 'अंगरेज़ी (فاڪ لينڊ ٻيٽ)',
         'en_FM' => 'अंगरेज़ी (مائڪرونيشيا)',
         'en_GB' => 'अंगरेज़ी (बरतानी)',
-        'en_GD' => 'अंगरेज़ी (گرينڊا)',
+        'en_GD' => 'अंगरेज़ी (گريناڊا)',
         'en_GG' => 'अंगरेज़ी (گورنسي)',
         'en_GH' => 'अंगरेज़ी (گهانا)',
         'en_GI' => 'अंगरेज़ी (جبرالٽر)',
@@ -67,6 +68,7 @@ return [
         'en_GU' => 'अंगरेज़ी (گوام)',
         'en_GY' => 'अंगरेज़ी (گيانا)',
         'en_HK' => 'अंगरेज़ी (هانگ ڪانگ SAR)',
+        'en_ID' => 'अंगरेज़ी (انڊونيشيا)',
         'en_IE' => 'अंगरेज़ी (آئرلينڊ)',
         'en_IL' => 'अंगरेज़ी (اسرائيل)',
         'en_IM' => 'अंगरेज़ी (انسانن جو ٻيٽ)',
@@ -88,6 +90,7 @@ return [
         'en_MS' => 'अंगरेज़ी (مونٽسراٽ)',
         'en_MT' => 'अंगरेज़ी (مالٽا)',
         'en_MU' => 'अंगरेज़ी (موريشس)',
+        'en_MV' => 'अंगरेज़ी (مالديپ)',
         'en_MW' => 'अंगरेज़ी (مالاوي)',
         'en_MY' => 'अंगरेज़ी (ملائيشيا)',
         'en_NA' => 'अंगरेज़ी (نيميبيا)',
@@ -99,7 +102,7 @@ return [
         'en_NZ' => 'अंगरेज़ी (نيو زيلينڊ)',
         'en_PG' => 'अंगरेज़ी (پاپوا نیو گني)',
         'en_PH' => 'अंगरेज़ी (فلپائن)',
-        'en_PK' => 'अंगरेज़ी (پاڪستان)',
+        'en_PK' => 'अंगरेज़ी (पाकिस्तान)',
         'en_PN' => 'अंगरेज़ी (پٽڪئرن ٻيٽ)',
         'en_PR' => 'अंगरेज़ी (پيوئرٽو ريڪو)',
         'en_PW' => 'अंगरेज़ी (پلائو)',
@@ -183,7 +186,7 @@ return [
         'fr_CF' => 'फ्रेंच (وچ آفريقي جمهوريه)',
         'fr_CG' => 'फ्रेंच (ڪانگو - برازاویل)',
         'fr_CH' => 'फ्रेंच (سوئزرلينڊ)',
-        'fr_CI' => 'फ्रेंच (ڪوٽ ڊي وار)',
+        'fr_CI' => 'फ्रेंच (ڪوٽي ويرا)',
         'fr_CM' => 'फ्रेंच (ڪيمرون)',
         'fr_DJ' => 'फ्रेंच (ڊجبيوتي)',
         'fr_DZ' => 'फ्रेंच (الجيريا)',
@@ -223,6 +226,8 @@ return [
         'gd_GB' => 'اسڪاٽش گيلڪ (बरतानी)',
         'gu_IN' => 'گجراتي (भारत)',
         'hi_IN' => 'هندي (भारत)',
+        'hi_Latn' => 'هندي (लैटिन)',
+        'hi_Latn_IN' => 'هندي (लैटिन, भारत)',
         'ii_CN' => 'سچوان يي (चीन)',
         'it' => 'इटालियनु',
         'it_CH' => 'इटालियनु (سوئزرلينڊ)',
@@ -231,20 +236,28 @@ return [
         'it_VA' => 'इटालियनु (ويٽڪين سٽي)',
         'ja' => 'जापानी',
         'ja_JP' => 'जापानी (जापान)',
+        'kk_Cyrl' => 'قازق (सिरिलिक)',
+        'kk_Cyrl_KZ' => 'قازق (सिरिलिक, قازقستان)',
         'kn_IN' => 'ڪناڊا (भारत)',
+        'ko_CN' => 'ڪوريائي (चीन)',
         'ks_Arab' => 'ڪشميري (अरबी)',
         'ks_Arab_IN' => 'ڪشميري (अरबी, भारत)',
+        'ks_Deva' => 'ڪشميري (देवनागिरी)',
+        'ks_Deva_IN' => 'ڪشميري (देवनागिरी, भारत)',
         'ks_IN' => 'ڪشميري (भारत)',
         'kw_GB' => 'ڪورنش (बरतानी)',
         'ml_IN' => 'مليالم (भारत)',
         'mr_IN' => 'مراٺي (भारत)',
         'ne_IN' => 'نيپالي (भारत)',
+        'oc_FR' => 'آڪسيٽن (फ़्रांस)',
         'or_IN' => 'اوڊيا (भारत)',
         'os_RU' => 'اوسيٽڪ (रशिया)',
         'pa_Arab' => 'پنجابي (अरबी)',
-        'pa_Arab_PK' => 'پنجابي (अरबी, پاڪستان)',
+        'pa_Arab_PK' => 'پنجابي (अरबी, पाकिस्तान)',
         'pa_Guru_IN' => 'پنجابي (گرمکي, भारत)',
         'pa_IN' => 'پنجابي (भारत)',
+        'pa_PK' => 'پنجابي (पाकिस्तान)',
+        'ps_PK' => 'پشتو (पाकिस्तान)',
         'pt' => 'पुर्तगाली',
         'pt_AO' => 'पुर्तगाली (انگولا)',
         'pt_BR' => 'पुर्तगाली (ब्राज़ील)',
@@ -269,16 +282,17 @@ return [
         'sc_IT' => 'سارڊيني (इटली)',
         'sd' => 'सिन्धी',
         'sd_Arab' => 'सिन्धी (अरबी)',
-        'sd_Arab_PK' => 'सिन्धी (अरबी, پاڪستان)',
+        'sd_Arab_PK' => 'सिन्धी (अरबी, पाकिस्तान)',
         'sd_Deva' => 'सिन्धी (देवनागिरी)',
         'sd_Deva_IN' => 'सिन्धी (देवनागिरी, भारत)',
-        'sd_PK' => 'सिन्धी (پاڪستان)',
+        'sd_IN' => 'सिन्धी (भारत)',
+        'sd_PK' => 'सिन्धी (पाकिस्तान)',
         'sr_Cyrl' => 'سربيائي (सिरिलिक)',
-        'sr_Cyrl_BA' => 'سربيائي (सिरिलिक, بوسنيا ۽ ھرزيگوينا)',
+        'sr_Cyrl_BA' => 'سربيائي (सिरिलिक, بوسنيا ۽ هرزوگووينا)',
         'sr_Cyrl_ME' => 'سربيائي (सिरिलिक, مونٽي نيگرو)',
         'sr_Cyrl_RS' => 'سربيائي (सिरिलिक, سربيا)',
         'sr_Latn' => 'سربيائي (लैटिन)',
-        'sr_Latn_BA' => 'سربيائي (लैटिन, بوسنيا ۽ ھرزيگوينا)',
+        'sr_Latn_BA' => 'سربيائي (लैटिन, بوسنيا ۽ هرزوگووينا)',
         'sr_Latn_ME' => 'سربيائي (लैटिन, مونٽي نيگرو)',
         'sr_Latn_RS' => 'سربيائي (लैटिन, سربيا)',
         'su_Latn' => 'سوڊاني (लैटिन)',
@@ -288,12 +302,14 @@ return [
         'tt_RU' => 'تاتار (रशिया)',
         'ug_CN' => 'يوغور (चीन)',
         'ur_IN' => 'اردو (भारत)',
+        'ur_PK' => 'اردو (पाकिस्तान)',
         'uz_Arab' => 'ازبڪ (अरबी)',
         'uz_Arab_AF' => 'ازبڪ (अरबी, افغانستان)',
         'uz_Cyrl' => 'ازبڪ (सिरिलिक)',
         'uz_Cyrl_UZ' => 'ازبڪ (सिरिलिक, ازبڪستان)',
         'uz_Latn' => 'ازبڪ (लैटिन)',
         'uz_Latn_UZ' => 'ازبڪ (लैटिन, ازبڪستان)',
+        'za_CN' => 'جوئنگ (चीन)',
         'zh' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी]',
         'zh_CN' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (चीन)',
         'zh_HK' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (هانگ ڪانگ SAR)',
@@ -301,10 +317,12 @@ return [
         'zh_Hans_CN' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], चीन)',
         'zh_Hans_HK' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], هانگ ڪانگ SAR)',
         'zh_Hans_MO' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], مڪائو SAR چين)',
+        'zh_Hans_MY' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], ملائيشيا)',
         'zh_Hans_SG' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], سنگاپور)',
         'zh_Hant' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे])',
         'zh_Hant_HK' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], هانگ ڪانگ SAR)',
         'zh_Hant_MO' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], مڪائو SAR چين)',
+        'zh_Hant_MY' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], ملائيشيا)',
         'zh_Hant_TW' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], تائیوان)',
         'zh_MO' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (مڪائو SAR چين)',
         'zh_SG' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (سنگاپور)',
